@@ -17,6 +17,15 @@ class Todo(TodoBase, table=True):
     project: Optional['Project'] = Relationship(back_populates='todos')
 
 
+class TodoUpdate(SQLModel):
+    description: Optional[str] = None
+    priority: Optional[str] = None
+    status: Optional[str] = None
+    tags: list[str] | None = None
+    due_date: datetime | None = None
+    project_id: Optional[int] = None
+
+
 class TodoCreate(TodoBase):
     pass
 
@@ -39,4 +48,16 @@ class ProjectCreate(ProjectBase):
 
 
 class ProjectRead(ProjectBase):
-    id: int
\ No newline at end of file
+    id: int
+
+
+class ProjectUpdate(SQLModel):
+    name: Optional[str] = None
+
+
+class TodoReadWithProject(TodoRead):
+    project: Optional[ProjectRead] = None
+
+
+class ProjectReadWithTodos(ProjectRead):
+    todos: list[TodoRead] = []
\ No newline at end of file
